@@ -10,96 +10,38 @@ use DBIx::EAV::EntityType;
 use DBIx::EAV::Entity;
 use DBIx::EAV::ResultSet;
 use DBIx::EAV::Schema;
-use constant {
-    SQL_DEBUG => $ENV{DBIX_EAV_TRACE}
-};
 use Carp qw/croak confess/;
 use Scalar::Util 'blessed';
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 # required
 has 'dbh', is => 'ro', required => 1;
 
-# optional
+# options
 has 'database_cascade_delete', is => 'ro', default => 0;
 has 'table_prefix', is => 'ro', default => 'eav_';
 has 'tenant_id', is => 'ro';
-has 'data_types', is => 'ro', default => sub { [qw/ int decimal varchar text datetime boolean /] };
-has 'schema', is => 'rw';
+has 'data_types', is => 'ro', default => sub { [qw/ int decimal varchar text datetime bool /] };
+has 'static_attributes', is => 'ro', default => sub { [] };
 has 'default_data_type', is => 'ro', default => 'varchar';
 
 # internal
+has 'schema', is => 'ro', lazy => 1, builder => 1, init_arg => undef, handles => [qw/ table dbh_do/];
 has '_types', is => 'ro', default => sub { {} };
 has '_types_by_id', is => 'ro', default => sub { {} };
 
 
-sub BUILD {
+sub _build_schema {
     my $self = shift;
 
-    my %schema_params = (
+    DBIx::EAV::Schema->new(
         dbh          => $self->dbh,
         tenant_id    => $self->tenant_id,
-        table_prefix => $self->table_prefix
-    );
-
-    # must be one of: (DBIx::EAV::)Schema instance, Schema subclass name, or Schema config
-    if (defined $self->schema) {
-
-        my $schema = $self->schema;
-
-        if (blessed $schema) {
-            die sprintf("invalid schema: %s is not a DBIx::EAV::Schema or subclass.", ref $schema)
-                unless $schema->isa('DBIx::EAV::Schema');
-
-            $schema->tenant_id($self->tenant_id);
-        }
-        else {
-
-            if (ref $schema eq 'HASH') {
-                $self->schema(DBIx::EAV::Schema->new( %schema_params ))
-            }
-            elsif (ref $schema eq '') {
-                require $schema;
-                $self->schema($schema->new( %schema_params ));
-            }
-            else {
-                die "Invalid schema. Must be one of: (DBIx::EAV::)Schema instance, Schema subclass name, or Schema config";
-            }
-        }
-    }
-    else {
-
-        my $schema = DBIx::EAV::Schema->new(
-            %schema_params,
-            tables => {
-
-                entities =>
-                    [qw/ id tenant_id entity_type_id created_at updated_at is_deleted is_active is_published /],
-
-                entity_types =>
-                    [qw/ id tenant_id name /],
-
-                attributes =>
-                    [qw/ id tenant_id entity_type_id name data_type /],
-
-                relationships =>
-                    [qw/ id tenant_id name left_entity_type_id right_entity_type_id is_has_one is_has_many is_many_to_many /],
-
-                entity_relationships =>
-                    [qw/ relationship_id left_entity_id right_entity_id /],
-
-                type_hierarchy =>
-                    [qw/ parent_type_id child_type_id /],
-
-                map {
-                    ("value_$_" => [qw/ entity_id attribute_id value /])
-                } @{ $self->data_types }
-            }
-        );
-
-        $self->schema($schema);
-    }
+        table_prefix => $self->table_prefix,
+        data_types   => $self->data_types,
+        static_attributes => $self->static_attributes
+    )
 }
 
 sub connect {
@@ -124,23 +66,6 @@ sub db_driver_name {
 }
 
 
-
-sub dbh_do {
-    my ($self, $stmt, $bind) = @_;
-
-    if (SQL_DEBUG) {
-        my $i = 0;
-        printf STDERR "$stmt: %s\n",
-            join('  ', map { $i++.'='.$_ } @{ $bind || [] });
-    }
-
-    my $sth = $self->dbh->prepare($stmt);
-    my $rv = $sth->execute(ref $bind eq 'ARRAY' ? @$bind : ());
-    die $sth->errstr unless defined $rv;
-
-    return ($rv, $sth);
-}
-
 sub has_data_type {
     my ($self, $name) = @_;
     foreach (@{$self->data_types}) {
@@ -149,10 +74,6 @@ sub has_data_type {
     0;
 }
 
-sub table {
-    my ($self, $name) = @_;
-    $self->schema->table($name);
-}
 
 sub has_type {
     my ($self, $name) = @_;
@@ -334,17 +255,18 @@ __END__
 
 =head1 NAME
 
-DBIx::EAV - Entity-Attribute-Value data modeling (aka 'open schema') over DBI
+DBIx::EAV - Entity-Attribute-Value data modeling (aka 'open schema') for Perl
 
 =head1 SYNOPSIS
 
     my $eav = DBIx::EAV->new( dbh => $dbh, %constructor_params );
 
     # or
-    my $eav = DBIx::EAV->connect( \%connect_info, \%constructor_params );
+    my $eav = DBIx::EAV->connect( $dbi_dsn, $dbi_user, $dbi_pass, $dbi_attrs, \%constructor_params );
 
     # define the entities schema
     my %schema = (
+
         Artist => {
             has_many     => 'Review',
             many_to_many => 'CD',
@@ -353,6 +275,7 @@ DBIx::EAV - Entity-Attribute-Value data modeling (aka 'open schema') over DBI
 
         CD => {
             has_many     => ['Track', 'Review'],
+            has_one      => ['CoverImage'],
             attributes   => [qw/ title description:text rating:int /]
         },
 
@@ -360,6 +283,10 @@ DBIx::EAV - Entity-Attribute-Value data modeling (aka 'open schema') over DBI
             attributes   => [qw/ title description:text duration:int /]
         },
 
+        CoverImage => {
+            attributes   => [qw/ url /]
+        },
+
         Review => {
             attributes => [qw/ content:text likes:int dislikes:int /]
         },
@@ -374,7 +301,7 @@ DBIx::EAV - Entity-Attribute-Value data modeling (aka 'open schema') over DBI
     $eav->register_schema(\%schema);
 
     # insert data (and possibly related data)
-    my $bob = $eav->model('Artist')->insert({
+    my $bob = $eav->resultset('Artist')->insert({
             name => 'Robert',
             description => '...',
             cds => [
@@ -403,15 +330,15 @@ DBIx::EAV - Entity-Attribute-Value data modeling (aka 'open schema') over DBI
 
 
     # retrieve Bob from database
-    my $bob = $eav->resultset('Artist')->find_one({ name => 'Bob' });
+    my $bob = $eav->resultset('Artist')->find({ name => 'Bob' });
 
     # retrieve Bob's cds from CD collection
-    my @cds = $eav->resultset('CD')->find({ artist => $bob })->all; # which is the same as: $bob->get('cds')->all
+    my @cds = $eav->resultset('CD')->search({ artist => $bob })->all; # which is the same as: $bob->get('cds')->all
 
     # or traverse the cds using the cursor
-    my $cds = $eav->resultset('CD')->find({ artist => $bob });
+    my $cds_rs = $eav->resultset('CD')->search({ artist => $bob });
 
-    while (my $cd = $cds->next) {
+    while (my $cd = $cds_rs->next) {
         print $cd->get('title');
     }
 
